==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/zh_CN.js <==
OC.L10N.register(
    "text",
    {
    "Text" : "文本 ",
    "📝 Collaborative document editing" : "文档协作编辑",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
    "Use current version" : "使用当前版本",
    "Use the saved version" : "使用保存的版本",
    "The document has been changed outside of the editor. The changes cannot be applied." : "本文档在编辑器外被更改。无法应用更改。",
    "Network connection error: Could not connect to the document" : "网络连接错误：无法连接到文档",
    "Retry" : "重试",
    "Last save {lastSave}" : "最近保存 {lastSave}",
    "Unpushed changes" : "未推送的更改",
    "Unsaved changes" : "未保存的更改",
    "Enter your name so other users can see who is editing" : "输入您的姓名以便他人看到谁在编辑",
    "Edit guest name" : "编辑访客姓名",
    "Save guest name" : "保存访客姓名",
    "Insert image" : "插入图片",
    "Add link" : "添加链接",
    "_and %n other editor_::_and %n other editors_" : ["和 %n 位其他编辑者"],
    "Show image" : "显示图片",
    "Show file" : "显示文件",
    "New text document" : "新建文本文档",
    "New text document.md" : "新建文本文档.md",
    "Edit" : "编辑",
    "Undo" : "撤销",
    "Redo" : "重做",
    "Bold" : "加粗",
    "Italic" : "斜体",
    "Strikethrough" : "删除线",
    "Paragraph" : "段落",
    "Headings" : "标题",
    "Heading 1" : "标题 1",
    "Heading 2" : "标题 2",
    "Heading 3" : "标题 3",
    "Heading 4" : "标题 4",
    "Heading 5" : "标题 5",
    "Heading 6" : "标题 6",
    "Unordered list" : "无编号列表",
    "Ordered list" : "编号列表",
    "Blockquote" : "块引用",
    "Code block" : "代码块"
},
"nplurals=1; plural=0;");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/zh_CN.js <==
OC.L10N.register(
    "text",
    {
    "Text" : "文本 ",
    "📝 Collaborative document editing" : "文档协作编辑",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
    "Use current version" : "使用当前版本",
    "Use the saved version" : "使用保存的版本",
    "The document has been changed outside of the editor. The changes cannot be applied." : "本文档在编辑器外被更改。无法应用更改。",
    "Network connection error: Could not connect to the document" : "网络连接错误：无法连接到文档",
    "Retry" : "重试",
    "Last save {lastSave}" : "最近保存 {lastSave}",
    "Unpushed changes" : "未推送的更改",
    "Unsaved changes" : "未保存的更改",
    "Enter your name so other users can see who is editing" : "输入您的姓名以便他人看到谁在编辑",
    "Edit guest name" : "编辑访客姓名",
    "Save guest name" : "保存访客姓名",
    "Insert image" : "插入图片",
    "Add link" : "添加链接",
    "_and %n other editor_::_and %n other editors_" : ["和 %n 位其他编辑者"],
    "Show image" : "显示图片",
    "Show file" : "显示文件",
    "New text document" : "新建文本文档",
    "Edit" : "编辑",
    "Undo" : "撤销",
    "Redo" : "重做",
    "Bold" : "加粗",
    "Italic" : "斜体",
    "Strikethrough" : "删除线",
    "Paragraph" : "段落",
    "Headings" : "标题",
    "Heading 1" : "标题 1",
    "Heading 2" : "标题 2",
    "Heading 3" : "标题 3",
    "Heading 4" : "标题 4",
    "Heading 5" : "标题 5",
    "Heading 6" : "标题 6",
    "Unordered list" : "无编号列表",
    "Ordered list" : "编号列表",
    "Blockquote" : "块引用",
    "Code block" : "代码块",
    "New text document.md" : "新建文本文档.md"
},
"nplurals=1; plural=0;");
